#[repr(C)]pub struct InstanceAddLineRequest {
pub line: [Point; 2],
}Expand description
The wire type corresponding to InstanceAddLineRequest.
Fields
line: [Point; 2]Trait Implementations
Sourceimpl Clone for InstanceAddLineRequest
impl Clone for InstanceAddLineRequest
Sourcefn clone(&self) -> InstanceAddLineRequest
fn clone(&self) -> InstanceAddLineRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for InstanceAddLineRequest
impl Constrained for InstanceAddLineRequest
Sourceimpl Debug for InstanceAddLineRequest
impl Debug for InstanceAddLineRequest
Sourceimpl<___D> Decode<___D> for InstanceAddLineRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for InstanceAddLineRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<InstanceAddLineRequest, ___E> for &'a InstanceAddLineRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InstanceAddLineRequest, ___E> for &'a InstanceAddLineRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InstanceAddLineRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InstanceAddLineRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InstanceAddLineRequest, ___E> for InstanceAddLineRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InstanceAddLineRequest, ___E> for InstanceAddLineRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, InstanceAddLineRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, InstanceAddLineRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InstanceAddLineRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InstanceAddLineRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<InstanceAddLineRequest, ___E> for InstanceAddLineRequest<T0>
impl<___E, T0> Encode<InstanceAddLineRequest, ___E> for InstanceAddLineRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InstanceAddLineRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InstanceAddLineRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<InstanceAddLineRequest> for InstanceAddLineRequest
impl FromWire<InstanceAddLineRequest> for InstanceAddLineRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InstanceAddLineRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<InstanceAddLineRequest, Self>
Sourcefn from_wire(wire: InstanceAddLineRequest) -> Self
fn from_wire(wire: InstanceAddLineRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<InstanceAddLineRequest> for InstanceAddLineRequest
impl FromWireRef<InstanceAddLineRequest> for InstanceAddLineRequest
Sourcefn from_wire_ref(wire: &InstanceAddLineRequest) -> Self
fn from_wire_ref(wire: &InstanceAddLineRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for InstanceAddLineRequest
impl IntoNatural for InstanceAddLineRequest
Sourcetype Natural = InstanceAddLineRequest
type Natural = InstanceAddLineRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for InstanceAddLineRequest
impl Wire for InstanceAddLineRequest
Sourcetype Narrowed<'de> = InstanceAddLineRequest
type Narrowed<'de> = InstanceAddLineRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.